/* ui.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from ui.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>


#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};



GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);


GType boxes_ui_state_get_type (void) {
	static volatile gsize boxes_ui_state_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_ui_state_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_UI_STATE_NONE, "BOXES_UI_STATE_NONE", "none"}, {BOXES_UI_STATE_COLLECTION, "BOXES_UI_STATE_COLLECTION", "collection"}, {BOXES_UI_STATE_CREDS, "BOXES_UI_STATE_CREDS", "creds"}, {BOXES_UI_STATE_DISPLAY, "BOXES_UI_STATE_DISPLAY", "display"}, {BOXES_UI_STATE_WIZARD, "BOXES_UI_STATE_WIZARD", "wizard"}, {BOXES_UI_STATE_PROPERTIES, "BOXES_UI_STATE_PROPERTIES", "properties"}, {0, NULL, NULL}};
		GType boxes_ui_state_type_id;
		boxes_ui_state_type_id = g_enum_register_static ("BoxesUIState", values);
		g_once_init_leave (&boxes_ui_state_type_id__volatile, boxes_ui_state_type_id);
	}
	return boxes_ui_state_type_id__volatile;
}


void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesUIState _tmp3_ = 0;
	BoxesUIState _tmp4_ = 0;
	BoxesUIState _tmp5_ = 0;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	_tmp0_ = boxes_ui_get_ui_state (self);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	_tmp1_ = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	_tmp2_ = new_state;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	if (_tmp1_ == _tmp2_) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
		return;
#line 78 "ui.c"
	}
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	_tmp3_ = boxes_ui_get_ui_state (self);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	_tmp4_ = _tmp3_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	boxes_ui_set_previous_ui_state (self, _tmp4_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	_tmp5_ = new_state;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	boxes_ui_set_ui_state (self, _tmp5_);
#line 90 "ui.c"
}


BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	return BOXES_UI_GET_INTERFACE (self)->get_previous_ui_state (self);
#line 99 "ui.c"
}


void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	g_return_if_fail (self != NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	BOXES_UI_GET_INTERFACE (self)->set_previous_ui_state (self, value);
#line 108 "ui.c"
}


BoxesUIState boxes_ui_get_ui_state (BoxesUI* self) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	return BOXES_UI_GET_INTERFACE (self)->get_ui_state (self);
#line 117 "ui.c"
}


void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	g_return_if_fail (self != NULL);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	BOXES_UI_GET_INTERFACE (self)->set_ui_state (self, value);
#line 126 "ui.c"
}


static void boxes_ui_base_init (BoxesUIIface * iface) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	static gboolean initialized = FALSE;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
	if (!initialized) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
		initialized = TRUE;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
		g_object_interface_install_property (iface, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ui.vala"
		g_object_interface_install_property (iface, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 141 "ui.c"
	}
}


GType boxes_ui_get_type (void) {
	static volatile gsize boxes_ui_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_ui_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUIIface), (GBaseInitFunc) boxes_ui_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_ui_type_id;
		boxes_ui_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesUI", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_ui_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&boxes_ui_type_id__volatile, boxes_ui_type_id);
	}
	return boxes_ui_type_id__volatile;
}



